﻿#   Create and set permissions for User Redirected Folders
#
#   By Elvis Gustin
#
#   Permissions are set as is described on Technet
#   https://technet.microsoft.com/en-us/library/jj649078.aspx

#   Please fill those variables
$FolderPath = "C:\ServerShare\RedirectedFolders"
$DomainAdmin = "EM-Soft\Domain Admins"
$RedirectedGroup = "Everyone"
$Sharename = "RedirectedFolders"

#   Create Folder and remove NTFS Inheritence
New-Item $FolderPath -type directory
$Acl = get-acl $FolderPath
$acl.SetAccessRuleProtection($true,$false)

#   Set required NTFS permissions to folder
#   CREATOR OWNER - Full Control (Apply onto: Subfolders and Files Only) 
$inherit = [system.security.accesscontrol.InheritanceFlags]"ContainerInherit, ObjectInherit"
$propagation = [system.security.accesscontrol.PropagationFlags]"InheritOnly"
$accessrule = New-Object system.security.AccessControl.FileSystemAccessRule("CREATOR OWNER", "FullControl", $inherit, $propagation, "Allow")
$acl.AddAccessRule($accessrule)

#   System - Full Control (Apply onto: This Folder, Subfolders and Files)
$inherit = [system.security.accesscontrol.InheritanceFlags]"ContainerInherit, ObjectInherit"
$propagation = [system.security.accesscontrol.PropagationFlags]"NoPropagateInherit"
$accessrule = New-Object system.security.AccessControl.FileSystemAccessRule("NT AUTHORITY\SYSTEM", "FullControl", $inherit, $propagation, "Allow")
$acl.AddAccessRule($accessrule)

#   Domain Admins - Full Control (Apply onto: This Folder Only)
$accessrule = New-Object system.security.AccessControl.FileSystemAccessRule($DomainAdmin, "FullControl", "Allow")
$acl.AddAccessRule($accessrule)

#   Everyone - Create Folder/Append Data, List Folder/Read Data, Traverse Folders/Execute File (Apply onto: This Folder Only) 
$accessrule = New-Object system.security.AccessControl.FileSystemAccessRule($RedirectedGroup, "CreateDirectories, ListDirectory, Traverse", "Allow")
$acl.AddAccessRule($accessrule)

#   Apply permissions to folder
set-acl -aclobject $acl $FolderPath

#   Finaly Create a shared folder
New-SmbShare –Name $Sharename –Path $FolderPath -FullAccess $RedirectedGroup
